.. _emg3d-manual:

#####
emg3d
#####

Version: |version| ~ Date: |today|

.. include:: ../README.rst
  :start-after: sphinx-inclusion-marker

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: User Manual

   usage
   mgwhat
   theory
   cpu_and_ram
   references
   changelog
   credits

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: API

   solver
   code
